==> fastify-0.39.0.tgz: package/.github/ISSUE_TEMPLATE.md <==
#### You have already researched for similiar issues?
It's not uncommon that somebody already opened an issue or in best case it's already fixed but not merged. That's the reason why you should [search](https://github.com/fastify/fastify/issues) at first before submitting a new one.

#### Are you sure this is an issue with the fastify or are you just looking for some help?

Issues should only be posted in this repository after you have been able to reproduce
them and confirm that they are a bug or incorrect/missing information in the [docs](https://github.com/fastify/fastify/docs).

For all other questions, requests, help resolving an issue, or if you are not sure if this is
the right place, please do not open an issue here. Instead, try to find a solution in the community [Gitter Chat](https://gitter.im/fastify).

If you have issues with the [fastify.io](https://www.fastify.io) site, please open an issue [here](https://github.com/fastify/website/issues).

#### Is this a security related issue?

Do not open issues that might have security implications. It is critical that security related issues
are reported privately so we have time to address them before they become public knowledge. Please
email all security related issues to the [Fastify Team](https://github.com/fastify/fastify#team).

#### What are you trying to achieve or the steps to reproduce?

Describe your issue here, include as much detail as neccessary to reproduce the issue
or implement a missing functionality. If you are reporting a bug, you will get faster response
if you submit a pull request with a failing test.

```js
// Wrap code in markdown source tags
```

#### What was the result you received?

#### What did you expect?

#### Context

* *node version*: 4,5,6,7,8,9
* *fastify version*: >=0.37.0
* *os*: Mac, Windows
* *any other relevant information*:

**Please read this entire template before posting any issue. If you ignore these instructions
and post an issue here that does not follow the instructions, your issue might be closed,
locked, and assigned the `missing discussion` label.**

==> fastify-1.0.0.tgz: package/.github/ISSUE_TEMPLATE.md <==
#### You have already researched for similiar issues?
It's not uncommon that somebody already opened an issue or in best case it's already fixed but not merged. That's the reason why you should [search](https://github.com/fastify/fastify/issues) at first before submitting a new one.

#### Are you sure this is an issue with the fastify or are you just looking for some help?

Issues should only be posted in this repository after you have been able to reproduce
them and confirm that they are a bug or incorrect/missing information in the [docs](https://github.com/fastify/fastify/docs).

For all other questions, requests, help resolving an issue, or if you are not sure if this is
the right place, please do not open an issue here. Instead, ask a question in our [help](https://github.com/fastify/help) repository or try to find a solution in the community [Gitter Chat](https://gitter.im/fastify).

If you have issues with the [fastify.io](https://www.fastify.io) site, please open an issue [here](https://github.com/fastify/website/issues).

#### Is this a security related issue?

Do not open issues that might have security implications. It is critical that security related issues
are reported privately so we have time to address them before they become public knowledge. Please
email all security related issues to the [Fastify Team](https://github.com/fastify/fastify#team).

#### What are you trying to achieve or the steps to reproduce?

Describe your issue here, include as much detail as neccessary to reproduce the issue
or implement a missing functionality. If you are reporting a bug, you will get faster response
if you submit a pull request with a failing test.

```js
// Wrap code in markdown source tags
```

#### What was the result you received?

#### What did you expect?

#### Context

* *node version*: 4,5,6,7,8,9
* *fastify version*: >=0.37.0
* *os*: Mac, Windows
* *any other relevant information*:

**Please read this entire template before posting any issue. If you ignore these instructions
and post an issue here that does not follow the instructions, your issue might be closed,
locked, and assigned the `missing discussion` label.**
